==> arch-hs-0.11.1.0-134.1-riscv64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-hs
version:              0.11.1.0
visibility:           public
id:                   arch-hs-0.11.1.0-5VL2A0Cni4VDfyQixujAeZ
key:                  arch-hs-0.11.1.0-5VL2A0Cni4VDfyQixujAeZ
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  c27808436646d32557b72ab952570177
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.11.1.0-5VL2A0Cni4VDfyQixujAeZ
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0/include
depends:
    Cabal-3.6.3.0 Diff-0.4.1-2b84kELbdFiFT3I48y9pel
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    algebraic-graphs-0.7-GZ9VdOedDcj31kxME60G6r
    arch-web-0.2-14CBI800eBJFEWdMkv6ryj base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    hackage-db-2.1.3-19sVzw3jEorC8hOoG3geC2
    http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-client-tls-0.3.6.3-vm9lZXKKPQG6YiMQwXwb7
    megaparsec-9.5.0-Bj42S1sxqz5CEZGEYlrAL4
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    neat-interpolation-0.5.1.4-1rLGA9c7v26KIeX7g0bx5L
    optparse-simple-0.1.1.4-7RhvNSpeqKDKRkMUDuP0Le
    polysemy-1.9.1.3-Lc3IEQUiVnB5n7JhYNTaB4
    prettyprinter-1.7.1-6qweuFXyH3M9iRh9d1UfvN
    prettyprinter-ansi-terminal-1.1.3-IJRJgLJFXarI2LfDjxVPUV
    servant-client-0.20-ANeZTzgUxwH9gRYRpGDNay
    split-0.2.5-9vnWwbrKvb7KEkhm7eawnM
    tar-conduit-0.4.1-INRrMkwnARaLKtFXxJPcO8 template-haskell-2.18.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> arch-hs-0.11.1.0-179-riscv64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-hs
version:              0.11.1.0
visibility:           public
id:                   arch-hs-0.11.1.0-BIvOhBM5aKAGLY7tBjlaN
key:                  arch-hs-0.11.1.0-BIvOhBM5aKAGLY7tBjlaN
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  459c57587129fe317d02cdd300f6b853
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.11.1.0-BIvOhBM5aKAGLY7tBjlaN
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.2.8/site-local/arch-hs-0.11.1.0/include
depends:
    Cabal-3.6.3.0 Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    algebraic-graphs-0.7-9jxeWDlP4Z56cqJRZXXbQL
    arch-web-0.2-Up5GzlXDDZ6EO4r6prGGm base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    hackage-db-2.1.3-6cMCwwk2xbQ9bYSUlE92yk
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6
    neat-interpolation-0.5.1.4-FoHLeyx64Ek6faAulgi96Y
    optparse-simple-0.1.1.4-Bu8q3G81wzHHNYn6fJKJcN
    polysemy-1.9.1.3-JLYTG64U1dy7gQAAUqpbEk
    prettyprinter-1.7.1-6Wsg7uF6NF3C9EkVjlD5S1
    prettyprinter-ansi-terminal-1.1.3-8oO97RT2laQgzPfmsyMvY
    servant-client-0.20-8D8xgQkcaQD1l8EGN94lYc
    split-0.2.5-L5qB0eGVSdY6HJmwsU4RMl
    tar-conduit-0.4.1-20mOsnRrcVG8cOntV4mUy1 template-haskell-2.18.0.0
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
